@@ -561,7 +561,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
     def id(self) -> builtins.str:
         '''The id of this construct within the current scope.
 
-        This is a a scope-unique id. To obtain an app-unique id for this construct, use ``uniqueId``.
+        This is a a scope-unique id. To obtain an app-unique id for this construct, use ``addr``.
         '''
         return typing.cast(builtins.str, jsii.get(self, "id"))
 
